==> kubernetes-model-1.0.42-sources.jar: annotations/io/fabric8/openshift/api/model/NamedTagEventListBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class NamedTagEventListBuilder extends NamedTagEventListFluentImpl<NamedTagEventListBuilder> implements VisitableBuilder<NamedTagEventList,NamedTagEventListBuilder>{

     NamedTagEventListFluent<?> fluent;
public NamedTagEventListBuilder(){
    this(new NamedTagEventList());
}
public NamedTagEventListBuilder( NamedTagEventListFluent<?> fluent ){
    this(fluent, new NamedTagEventList());
}
public NamedTagEventListBuilder( NamedTagEventListFluent<?> fluent , NamedTagEventList instance ){
    this.fluent = fluent; fluent.withConditions(instance.getConditions()); fluent.withItems(instance.getItems()); fluent.withTag(instance.getTag()); 
}
public NamedTagEventListBuilder( NamedTagEventList instance ){
    this.fluent = this; this.withConditions(instance.getConditions()); this.withItems(instance.getItems()); this.withTag(instance.getTag()); 
}

public EditableNamedTagEventList build(){
    EditableNamedTagEventList buildable = new EditableNamedTagEventList(fluent.getConditions(),fluent.getItems(),fluent.getTag());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedTagEventListBuilder that = (NamedTagEventListBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/openshift/api/model/NamedTagEventListBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.List;
import java.util.RandomAccess;
import java.util.List;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class NamedTagEventListBuilder extends NamedTagEventListFluentImpl<NamedTagEventListBuilder> implements VisitableBuilder<NamedTagEventList,NamedTagEventListBuilder>{

     NamedTagEventListFluent<?> fluent;
public NamedTagEventListBuilder(){
    this(new NamedTagEventList());
}
public NamedTagEventListBuilder( NamedTagEventListFluent<?> fluent ){
    this(fluent, new NamedTagEventList());
}
public NamedTagEventListBuilder( NamedTagEventListFluent<?> fluent , NamedTagEventList instance ){
    this.fluent = fluent; fluent.withConditions(instance.getConditions()); fluent.withItems(instance.getItems()); fluent.withTag(instance.getTag()); 
}
public NamedTagEventListBuilder( NamedTagEventList instance ){
    this.fluent = this; this.withConditions(instance.getConditions()); this.withItems(instance.getItems()); this.withTag(instance.getTag()); 
}

public NamedTagEventList build(){
    NamedTagEventList buildable = new NamedTagEventList(fluent.getConditions(),fluent.getItems(),fluent.getTag());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedTagEventListBuilder that = (NamedTagEventListBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
